@@ -39,6 +39,10 @@ enum {
         PROP_RELEASED,
         PROP_IMAGES,
         PROP_LAST_MODIFIED,
+        PROP_ADULT,
+        PROP_ORIGINAL_NAME,
+        PROP_VOTES,
+        PROP_VERSION,
 };
 
 #define GET_PRIVATE(o) \
@@ -61,6 +65,10 @@ struct _BtcTmdbMoviePrivate {
         gchar *released;
         GList *images;
         gchar *last_modified;
+        gchar *adult;
+        gchar *original_name;
+        gchar *votes;
+        gchar *version;
 };
 
 static void
@@ -115,6 +123,18 @@ btc_tmdb_movie_get_property (GObject *object, guint property_id,
         case PROP_URL:
                 g_value_set_string (value, self->priv->url);
                 break;
+        case PROP_ADULT:
+                g_value_set_string (value, self->priv->adult);
+                break;
+        case PROP_ORIGINAL_NAME:
+                g_value_set_string (value, self->priv->original_name);
+                break;
+        case PROP_VOTES:
+                g_value_set_string (value, self->priv->votes);
+                break;
+        case PROP_VERSION:
+                g_value_set_string (value, self->priv->version);
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         }
@@ -186,6 +206,22 @@ btc_tmdb_movie_set_property (GObject *object, guint property_id,
                 btc_tmdb_movie_set_url (self,
                                 g_value_get_string (value));
                 break;
+        case PROP_ADULT:
+                btc_tmdb_movie_set_adult (self,
+                                g_value_get_string (value));
+                break;
+        case PROP_ORIGINAL_NAME:
+                btc_tmdb_movie_set_original_name (self,
+                                g_value_get_string (value));
+                break;
+        case PROP_VOTES:
+                btc_tmdb_movie_set_votes (self,
+                                g_value_get_string (value));
+                break;
+        case PROP_VERSION:
+                btc_tmdb_movie_set_version (self,
+                                g_value_get_string (value));
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         }
@@ -211,6 +247,10 @@ btc_tmdb_movie_finalize (GObject *object)
         g_free (self->priv->translated);
         g_free (self->priv->type);
         g_free (self->priv->url);
+        g_free (self->priv->adult);
+        g_free (self->priv->original_name);
+        g_free (self->priv->votes);
+        g_free (self->priv->version);
 
         g_list_foreach (self->priv->images, (GFunc) g_object_unref, NULL);
         g_list_free (self->priv->images);
@@ -324,6 +364,34 @@ btc_tmdb_movie_class_init (BtcTmdbMovieClass *klass)
                          g_param_spec_string ("url", "Movie url", "The movie url",
                                  NULL,
                                  G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+
+        g_object_class_install_property
+                        (object_class, PROP_ADULT,
+                         g_param_spec_string ("adult", "Adult movie",
+                                              "Tells if it is an adult movie",
+                                              NULL,
+                                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+
+        g_object_class_install_property
+                        (object_class, PROP_ORIGINAL_NAME,
+                         g_param_spec_string ("original_name", "Original name",
+                                              "The original name",
+                                              NULL,
+                                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+
+        g_object_class_install_property
+                        (object_class, PROP_VOTES,
+                         g_param_spec_string ("votes", "Votes",
+                                              "The movie votes",
+                                              NULL,
+                                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+
+        g_object_class_install_property
+                        (object_class, PROP_VERSION,
+                         g_param_spec_string ("version", "Version",
+                                              "The movie version",
+                                              NULL,
+                                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
 static void
@@ -347,6 +415,10 @@ btc_tmdb_movie_init (BtcTmdbMovie *self)
         self->priv->translated = NULL;
         self->priv->type = NULL;
         self->priv->url = NULL;
+        self->priv->adult = NULL;
+        self->priv->original_name = NULL;
+        self->priv->votes = NULL;
+        self->priv->version = NULL;
 }
 
 BtcTmdbMovie*
@@ -575,6 +647,57 @@ btc_tmdb_movie_get_url (BtcTmdbMovie *self)
         return self->priv->url;
 }
 
+gboolean
+btc_tmdb_movie_set_adult (BtcTmdbMovie *self, const gchar *adult)
+{
+        g_return_val_if_fail (BTC_TMDB_MOVIE (self), FALSE);
+        return set_property (&self->priv->adult, adult);
+}
+
+const gchar*
+btc_tmdb_movie_get_adult (BtcTmdbMovie *self)
+{
+        return self->priv->adult;
+}
+
+gboolean
+btc_tmdb_movie_set_original_name (BtcTmdbMovie *self, const gchar *original_name)
+{
+        g_return_val_if_fail (BTC_TMDB_MOVIE (self), FALSE);
+        return set_property (&self->priv->original_name, original_name);
+}
+
+const gchar*
+btc_tmdb_movie_get_original_name (BtcTmdbMovie *self)
+{
+        return self->priv->original_name;
+}
+
+gboolean
+btc_tmdb_movie_set_votes (BtcTmdbMovie *self, const gchar *votes)
+{
+        g_return_val_if_fail (BTC_TMDB_MOVIE (self), FALSE);
+        return set_property (&self->priv->votes, votes);
+}
+
+const gchar*
+btc_tmdb_movie_get_votes (BtcTmdbMovie *self)
+{
+        return self->priv->votes;
+}
+
+gboolean
+btc_tmdb_movie_set_version (BtcTmdbMovie *self, const gchar *version)
+{
+        g_return_val_if_fail (BTC_TMDB_MOVIE (self), FALSE);
+        return set_property (&self->priv->version, version);
+}
+const gchar*
+btc_tmdb_movie_get_version (BtcTmdbMovie *self)
+{
+        return self->priv->version;
+}
+
 void
 btc_tmdb_movie_print (BtcTmdbMovie *self)
 {
@@ -597,4 +720,8 @@ btc_tmdb_movie_print (BtcTmdbMovie *self)
         g_print ("[Translated]: %s\n", self->priv->translated);
         g_print ("[Type]: %s\n", self->priv->type);
         g_print ("[URL]: %s\n", self->priv->url);
+        g_print ("[Adult]: %s\n", self->priv->adult);
+        g_print ("[Original name]: %s\n", self->priv->original_name);
+        g_print ("[Votes]: %s\n", self->priv->votes);
+        g_print ("[Version]: %s\n", self->priv->version);
 }
